package VMOMI::HostDiskPartitionInfoPartitionFormat;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
